@@ -4,6 +4,8 @@ import os
 from pathlib import Path
 import tarfile
 
+from gevent.fileobject import FileObject
+
 from firex_flame.event_aggregator import slim_tasks_by_uuid, COMPLETE_STATES
 from firex_flame.flame_helper import get_flame_debug_dir, query_full_tasks
 
@@ -12,7 +14,7 @@ logger = logging.getLogger(__name__)
 
 def _truncating_write_json(file, data):
     with open(file, 'w') as f:
-        json.dump(data, fp=f, sort_keys=True, indent=2)
+        json.dump(data, fp=FileObject(file, 'w'), sort_keys=True, indent=2)
 
 
 def get_flame_model_dir(firex_logs_dir):
@@ -48,13 +50,17 @@ def get_run_metadata_file(firex_logs_dir=None, root_model_dir=None):
     return os.path.join(_get_base_model_dir(firex_logs_dir, root_model_dir), 'run-metadata.json')
 
 
-def get_flame_url(firex_logs_dir=None, root_model_dir=None):
+def get_run_metadata(firex_logs_dir=None, root_model_dir=None):
     run_metadata_file = get_run_metadata_file(firex_logs_dir, root_model_dir)
     if os.path.isfile(run_metadata_file):
-        return json.loads(Path(run_metadata_file).read_text()).get('flame_url', None)
+        return json.loads(Path(run_metadata_file).read_text())
     return None
 
 
+def get_flame_url(firex_logs_dir=None, root_model_dir=None):
+    return get_run_metadata(firex_logs_dir, root_model_dir).get('flame_url', None)
+
+
 def get_tasks_slim_file(firex_logs_dir=None, root_model_dir=None):
     return os.path.join(_get_base_model_dir(firex_logs_dir, root_model_dir), 'slim-tasks.json')
 
